@@ -187,7 +187,7 @@ comments_get_comment_filename__old (const char *source,
 			    NULL);
 
 	if (!unescape) {
-		char *escaped_path = gnome_vfs_escape_host_and_path_string (path);
+		char *escaped_path = escape_uri (path);
 		g_free (path);
 		path = escaped_path;
 	}
@@ -274,7 +274,7 @@ comments_get_comment_filename (const char *source,
 	path = g_build_filename (directory, ".comments", filename, NULL);
 
 	if (!unescape) {
-		char *escaped_path = gnome_vfs_escape_host_and_path_string (path);
+		char *escaped_path = escape_uri (path);
 		g_free (path);
 		path = escaped_path;
 	}
@@ -769,66 +769,6 @@ comments_save_categories (const char  *filename,
 }
 
 
-char *
-comments_get_comment_as_string (CommentData *data, 
-				char        *sep1, 
-				char        *sep2)
-{
-	char      *as_string = NULL;
-	char       time_txt[50] = "";
-	char      *utf8_time_txt = NULL;
-	struct tm *tm;
-
-	if (data == NULL)
-		return NULL;
- 
-	if (data->time != 0) {
-		tm = localtime (& data->time);
-		if (tm->tm_hour + tm->tm_min + tm->tm_sec == 0)
-			strftime (time_txt, 50, _("%d %B %Y"), tm);
-		else
-			strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
-		utf8_time_txt = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
-	} 
-
-	if ((data->comment == NULL) 
-	    && (data->place == NULL) 
-	    && (data->time == 0)) {
-		if (data->keywords_n > 0) 
-			as_string = NULL;
-		else
-			as_string = g_strdup (_("(No Comment)"));
-	} else {
-		GString *comment;
-
-		comment = g_string_new ("");
-
-		if (data->comment != NULL) 
-			g_string_append (comment, data->comment);
-
-		if ((data->comment != NULL)
-		    && ((data->place != NULL) || (*time_txt != 0)))
-			g_string_append (comment, sep1);
-		
-		if (data->place != NULL) 
-			g_string_append (comment, data->place);
-
-		if ((data->place != NULL) && (*time_txt != 0))
-			g_string_append (comment, sep2);
-
-		if (utf8_time_txt != NULL) 
-			g_string_append (comment, utf8_time_txt);
-
-		as_string = comment->str;
-		g_string_free (comment, FALSE);
-	}
-
-	g_free (utf8_time_txt);
-
-	return as_string;
-}
-
-
 void
 comment_data_remove_keyword (CommentData *data,
 			     const char  *keyword)
@@ -904,3 +844,161 @@ comment_data_is_void (CommentData *data)
 
 	return TRUE;
 }
+
+
+/* From: glib/glib/gmarkup.c (Copyright 2000, 2003 Red Hat, Inc.)  
+ * This version does not escape ' and ''. Needed  because IE does not recognize
+ * &apos; and &quot; */
+static void
+_append_escaped_text_for_html (GString     *str,
+			       const gchar *text,
+			       gssize       length)
+{
+	const gchar *p;
+	const gchar *end;
+
+	p = text;
+	end = text + length;
+	
+	while (p != end) {
+		const gchar *next;
+		next = g_utf8_next_char (p);
+		
+		switch (*p) {
+		case '&':
+			g_string_append (str, "&amp;");
+			break;
+			
+		case '<':
+			g_string_append (str, "&lt;");
+			break;
+			
+		case '>':
+			g_string_append (str, "&gt;");
+			break;
+			
+		default:
+			g_string_append_len (str, p, next - p);
+			break;
+		}
+		
+		p = next;
+	}
+}
+
+
+char*
+_g_escape_text_for_html (const gchar *text,
+			 gssize       length)
+{
+	GString *str;
+
+	g_return_val_if_fail (text != NULL, NULL);
+	
+	if (length < 0)
+		length = strlen (text);
+
+	/* prealloc at least as long as original text */
+	str = g_string_sized_new (length);
+	_append_escaped_text_for_html (str, text, length);
+
+	return g_string_free (str, FALSE);
+}
+
+
+static void
+_string_append (GString    *str,
+		const char *a,
+		gboolean    markup_escape) 
+{
+	if (a == NULL)
+		return;
+
+ 	if (markup_escape)
+		_append_escaped_text_for_html (str, a, strlen (a));
+	else 
+		g_string_append (str, a);
+}
+
+
+/* Note: separators are not escaped */
+static char *
+_get_comment_as_string_common (CommentData *data, 
+			       char        *sep1, 
+			       char        *sep2,
+			       gboolean     markup_escape)
+{
+	char      *as_string = NULL;
+	char       time_txt[50] = "";
+	char      *utf8_time_txt = NULL;
+	struct tm *tm;
+
+	if (data == NULL)
+		return NULL;
+ 
+	if (data->time != 0) {
+		tm = localtime (& data->time);
+		if (tm->tm_hour + tm->tm_min + tm->tm_sec == 0)
+			strftime (time_txt, 50, _("%d %B %Y"), tm);
+		else
+			strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
+		utf8_time_txt = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
+	} 
+
+	if ((data->comment == NULL) 
+	    && (data->place == NULL) 
+	    && (data->time == 0)) {
+		if (data->keywords_n > 0) 
+			as_string = NULL;
+		else if (markup_escape)
+			as_string = g_markup_escape_text (_("(No Comment)"), -1);
+		else
+			as_string = g_strdup (_("(No Comment)"));
+		
+	} else {
+		GString *comment;
+
+		comment = g_string_new ("");
+
+		if (data->comment != NULL) 
+			_string_append (comment, data->comment, markup_escape);
+
+		if ((data->comment != NULL)
+		    && ((data->place != NULL) || (*time_txt != 0)))
+			g_string_append (comment, sep1);
+		
+		if (data->place != NULL) 
+			_string_append (comment, data->place, markup_escape);
+
+		if ((data->place != NULL) && (*time_txt != 0))
+			g_string_append (comment, sep2);
+		
+		if (utf8_time_txt != NULL) 
+			_string_append (comment, utf8_time_txt, markup_escape);
+		
+		as_string = comment->str;
+		g_string_free (comment, FALSE);
+	}
+	
+	g_free (utf8_time_txt);
+	
+	return as_string;
+}
+
+
+char *
+comments_get_comment_as_string (CommentData *data, 
+				char        *sep1, 
+				char        *sep2)
+{
+	return _get_comment_as_string_common (data, sep1, sep2, FALSE);
+}
+
+
+char *
+comments_get_comment_as_xml_string (CommentData *data, 
+				    char        *sep1, 
+				    char        *sep2)
+{
+	return _get_comment_as_string_common (data, sep1, sep2, TRUE);
+}
